<?PHP

global $CFG;
//require_once("../../config.php");
require_once($CFG->dirroot.'/lib/dmllib.php');
require_once($CFG->dirroot.'/lib/questionlib.php');
require_once($CFG->dirroot.'/mod/quiz/lib.php');
require_once($CFG->dirroot.'/mod/quiz/locallib.php');

// Load all the questions (and answers) for a quiz
function quizex_load_questions( $quiz ) {
	global $CFG;

	$questionlist = quiz_questions_in_quiz($quiz->questions);

	$sql = "SELECT q.*, i.grade AS maxgrade, i.id AS instance".
		   "  FROM {$CFG->prefix}question q,".
	       "       {$CFG->prefix}quiz_question_instances i".
		   " WHERE i.quiz = '$quiz->id' AND q.id = i.question".
		   "   AND q.id IN ($questionlist)";

	if (!$questions = get_records_sql($sql)) {
		error(get_string('noquestionsfound', 'quiz'));
		return 0;
	}


	if (!get_question_options($questions)) {
		error('could not load question options');
		return 0;
	}

	// Add each question in order
	$quiz->questionarray = array();
	$list = explode(",", $questionlist);
	foreach ( $list as $question_id ) {

		$question = $questions[$question_id];

		// push question to end of list
		$quiz->questionarray[] = $question;
	}

	return $quiz;
} 

// Get current language in RFC3066 format eg 'fr-CA' for French spoken in Canada
function quizex_get_rfc3066_lang() {
	$lang = current_language();

	# Remove _utf8 at end
	$lang = preg_replace( '/_utf8$/', '', $lang ); 

	# convert _region to -REGION
	$lang = preg_replace( '/(\w+)_(\w+)/e', "'\\1'.'-'.strtoupper('\\2')", $lang ); 

	return $lang;
}

function quizex_clean_html( $html ) {
	$html = html_entity_decode( $html, ENT_NOQUOTES, 'UTF-8' );
	$html = strip_tags( $html );
	return $html;
}

// Safely create an element
function _quizex_createElement( $document, $name, $value ) {

	$node = $document->createElement($name);

	if (!is_null($value)) {
		$node->appendChild(
			$document->createTextNode($value)
		);
	}
	return $node;
}


// Convert a quiz to DOM
function quizex_get_dom($quiz) {

	$lang = quizex_get_rfc3066_lang();

	$document = new DOMDocument( '1.0', 'UTF-8' );
	$quiz_element = $document->createElement( 'quiz' );
	$quiz_element->setAttribute( 'version', '1.0' );
	if ( $lang ) {
		$quiz_element->setAttribute( 'xml:lang', $lang );
	}
	$quiz_element->appendChild( _quizex_createElement( $document, 'title', $quiz->name ) );
	$quiz_element->appendChild( _quizex_createElement( $document, 'intro', quizex_clean_html( $quiz->intro ) ) );

	$document->appendChild( $quiz_element );

	$questionlist = quiz_questions_in_quiz($quiz->questions);
	$list = explode(",", $questionlist);
	foreach ( $list as $question_id ) {

		$question = 0;
		foreach( $quiz->questionarray as $tmp_question ) {
			if ( $tmp_question->id == $question_id ) {
				$question = $tmp_question;
				break;
			}
		}

		if ( ! $question ) {
			break;
		}

		$question_element = $document->createElement( 'question' );
		$question_element->appendChild( 	
			_quizex_createElement( $document, 'title', quizex_clean_html( $question->questiontext ) ) 
		);
		$question_element->appendChild( 	
			_quizex_createElement( $document, 'explanation', quizex_clean_html( $question->generalfeedback ) )
		);

		if ( $question->qtype != 'essay' ) {
			foreach($question->options->answers as $answer) {


				$answer_element = $document->createElement( 'answer' );

				# Add is_correct attr
				if ( $answer->fraction == 1 ) {
					$answer_element->appendChild( new DOMAttr( 'is_correct', '1' ) );
				}

				# Add answer title element
				$answer_title = _quizex_createElement( $document, 'title', $answer->answer );
				$answer_element->appendChild( $answer_title );

				# Add answer to question
				$question_element->appendChild( $answer_element );
			}
		}

		$quiz_element->appendChild( $question_element );
	}

	$document->formatOutput = true;

	return $document;
}


?>
